/* gbp-flatpak-aux.h
 *
 * Copyright 2021 Christian Hergert <chergert@redhat.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <libide-foundry.h>
#include <libide-threading.h>

G_BEGIN_DECLS

void gbp_flatpak_aux_init                  (void);
int  gbp_flatpak_aux_apply                 (IdeSubprocessLauncher *launcher,
                                            int                    position);
void gbp_flatpak_aux_append_to_run_context (IdeRunContext         *run_context);

G_END_DECLS
